Module line_utils

Module line_utils 

Functions

is_blank_line_spaces_only
Consider a line blank if it has no spans or only spans whose contents are empty or consist solely of spaces (no tabs/newlines).
line_to_static
Clone a borrowed ratatui Line into an owned 'static line.
prefix_lines
Prefix each line with initial_prefix for the first line and subsequent_prefix for following lines. Returns a new Vec of owned lines.
push_owned_lines
Append owned copies of borrowed lines to out.